Type Definition shot_runtime::types::Signature [−][src]
pub type Signature = MultiSignature;Expand description
Alias to 512-bit hash when used in the context of a transaction signature on the chain.
pub type Signature = MultiSignature;Alias to 512-bit hash when used in the context of a transaction signature on the chain.